@@ -35,7 +35,7 @@ class Query(object):
             "Accept": "application/json",
             "Authorization": "token {token}".format(token=self._token),
             "X-API-Version": "20151130",
-            "User-Agent": "Python API 1.87 / {local_version}".format(local_version=platform.python_version())
+            "User-Agent": "Python API 1.88 / {local_version}".format(local_version=platform.python_version())
         }
         self._dataset_id = None
         self._tickers = []
@@ -115,13 +115,45 @@ class Query(object):
 
     def reset_tickers(self):
         del self._tickers[:]
+    
+    def _get_condition_depth(self, condition):
+        for filter in self._filters:
+            for sub_filter in filter.get('conditions', []):
+                if sub_filter == condition:
+                    return 2
+            if filter == condition:
+                return 1
+        return None
 
-    def add_filter(self, column, type, value):
-        self._filters.append({
-            "column": column,
-            "type": type,
-            "value": value,
-        })
+    def add_condition(self, match, condition=None):
+        if not condition:
+            self._filters.append({
+                'match': match,
+                'conditions': []
+            })
+            return self._filters[-1]
+        else:
+            if self._get_condition_depth(condition) == 2:
+                raise Exception('Maximum depth of the condition is two')
+            condition['conditions'].append({
+                'match': match,
+                'conditions': []
+            })
+            return condition['conditions'][-1]
+
+    def add_filter(self, column, type, value, condition=None):
+        if not condition:
+            self._filters.append({
+                "column": column,
+                "type": type,
+                "value": value,
+            })
+        else:
+            condition['conditions'].append({
+                "column": column,
+                "type": type,
+                "value": value,
+            })
 
     def reset_filters(self):
         del self._filters[:]
